@@ -6,7 +6,7 @@ import torch
 from rust_circuit import Einsum, ScalarConstant, ArrayConstant, Symbol, Add, Rearrange, RearrangeSpec, Concat, Index
 
 # %%
-e = Einsum.from_einsum_string("a->", [ScalarConstant(0.2, (2,))])
+e = Einsum.from_einsum_string("a->", ScalarConstant(0.2, (2,)))
 e.compiler_print()
 
 x = Einsum(
