@@ -12,7 +12,7 @@ use super::{
     circuit_utils::has_leaf_symbols,
     compiler_heuristics::deep_maybe_distribute,
     compiler_strip::strip_names,
-    debugging::{create_circuit_test, randn_ablate_great_grandchildren},
+    debugging::randn_ablate_great_grandchildren,
     deep_map_op_context,
     deep_rewrite::deep_heuristic_nest_adds,
     deep_rewrite::{compiler_simp, deep_optimize_einsums, deep_push_down_index},
@@ -24,7 +24,7 @@ use super::{
 };
 use crate::circuit::CircResult;
 use crate::opt_einsum::EinsumSpec;
-use crate::{circuit::print::rust_expression_notation_circuit, pyo3_prelude::*};
+use crate::pyo3_prelude::*;
 use crate::{py_types::Tensor, timed, util::apply_fn_until_same};
 
 // a lot of the function boundries in this are there because it would be too hard to optimize things jointly
@@ -262,16 +262,6 @@ pub fn optimize_circuit(circuit: CircuitRc, context: &mut OptimizationContext) -
         let mut file = std::fs::File::create(f_name).unwrap();
         file.write_all(s.as_bytes()).unwrap();
     }
-    if context.settings.create_tests {
-        // Make compiler_simp tests here
-        let ablated = randn_ablate_great_grandchildren(circuit.clone());
-        create_circuit_test(
-            "compiler_simp",
-            ablated.clone(),
-            compiler_simp(ablated, context),
-        )
-        .unwrap();
-    }
     let circuit = timed!(compiler_simp(circuit, context), 10, print_timings);
     // originally tried push_down_index in compiler_simp, but that produced worse circuits
     // for unknown reasons, maybe i'll investigate
@@ -327,10 +317,7 @@ pub fn optimize_to_schedule(
         println!("Optimizing verbose {}", verbose)
     }
     if settings.capture_and_print {
-        println!(
-            "{}",
-            rust_expression_notation_circuit(circuit.clone(), true)
-        );
+        println!("{}", repr_circuit_deep_compiler(&**circuit, true, false));
     }
     let optimized_circuit = timed!(optimize_circuit(circuit, context), 10, verbose >= 1);
     // return evaluate_fn(&*optimized_circuit).unwrap();
