@@ -37,42 +37,40 @@ pub fn einsum_elim_removable_axes_weak(einsum: &Einsum) -> Option<Einsum> {
     if int_to_input_removable.len() == 0 {
         return None;
     }
-    return Some(
-        Einsum::new(
-            einsum
-                .args
-                .iter()
-                .enumerate()
-                .map(|(i, (node, ints))| {
-                    let removable_axes: HashSet<usize> = ints
-                        .iter()
-                        .enumerate()
-                        .filter_map(|(j, int)| {
-                            if int_to_input_removable
-                                .get(int)
-                                .map(|z| z.contains(&i))
-                                .unwrap_or(false)
-                            {
-                                Some(j)
-                            } else {
-                                None
-                            }
-                        })
-                        .collect();
-                    if removable_axes.len() == 0 {
-                        (node.clone(), ints.clone())
-                    } else {
-                        (
-                            remove_axes(node, &removable_axes).unwrap(),
-                            filter_out_idx(ints, &removable_axes).into_iter().collect(),
-                        )
-                    }
-                })
-                .collect(),
-            einsum.out_axes.clone(),
-            einsum.name_cloned(),
-        ),
-    );
+    return Some(Einsum::new(
+        einsum
+            .args
+            .iter()
+            .enumerate()
+            .map(|(i, (node, ints))| {
+                let removable_axes: HashSet<usize> = ints
+                    .iter()
+                    .enumerate()
+                    .filter_map(|(j, int)| {
+                        if int_to_input_removable
+                            .get(int)
+                            .map(|z| z.contains(&i))
+                            .unwrap_or(false)
+                        {
+                            Some(j)
+                        } else {
+                            None
+                        }
+                    })
+                    .collect();
+                if removable_axes.len() == 0 {
+                    (node.clone(), ints.clone())
+                } else {
+                    (
+                        remove_axes(node, &removable_axes).unwrap(),
+                        filter_out_idx(ints, &removable_axes).into_iter().collect(),
+                    )
+                }
+            })
+            .collect(),
+        einsum.out_axes.clone(),
+        einsum.name_cloned(),
+    ));
 }
 
 #[pyfunction]
@@ -105,40 +103,38 @@ pub fn add_elim_removable_axes_weak(add: &Add) -> Option<Add> {
     if axis_to_inputs_removable.len() == 0 {
         return None;
     }
-    Some(
-        Add::new(
-            add.nodes_and_rank_differences()
-                .iter()
-                .enumerate()
-                .map(|(i, (node, rank_dif))| {
-                    let removable_axes: HashSet<usize> = (*rank_dif..add.info().rank())
-                        .enumerate()
-                        .filter_map(|(j, int)| {
-                            if axis_to_inputs_removable
-                                .get(&int)
-                                .map(|z| z.contains(&i))
-                                .unwrap_or(false)
-                            {
-                                Some(j)
-                            } else {
-                                None
-                            }
-                        })
-                        .collect();
-                    if removable_axes.len() == 0 {
-                        node.clone()
-                    } else {
-                        expand_at_axes(
-                            remove_axes(node, &removable_axes).unwrap(),
-                            removable_axes.into_iter().collect(),
-                            None,
-                        )
-                    }
-                })
-                .collect(),
-            add.name_cloned(),
-        ),
-    )
+    Some(Add::new(
+        add.nodes_and_rank_differences()
+            .iter()
+            .enumerate()
+            .map(|(i, (node, rank_dif))| {
+                let removable_axes: HashSet<usize> = (*rank_dif..add.info().rank())
+                    .enumerate()
+                    .filter_map(|(j, int)| {
+                        if axis_to_inputs_removable
+                            .get(&int)
+                            .map(|z| z.contains(&i))
+                            .unwrap_or(false)
+                        {
+                            Some(j)
+                        } else {
+                            None
+                        }
+                    })
+                    .collect();
+                if removable_axes.len() == 0 {
+                    node.clone()
+                } else {
+                    expand_at_axes(
+                        remove_axes(node, &removable_axes).unwrap(),
+                        removable_axes.into_iter().collect(),
+                        None,
+                    )
+                }
+            })
+            .collect(),
+        add.name_cloned(),
+    ))
 }
 
 #[pyfunction]
