@@ -28,8 +28,9 @@ pub struct PyUtils {
     pub none: PyObject,
     einsum: PyObject,
     make_diagonal: PyObject,
-    make_bytes: PyObject,
     pub print: PyObject,
+    pub tensor_to_bytes: PyObject,
+    pub tensor_from_bytes: PyObject,
 }
 
 /// misc python utilities
@@ -66,8 +67,9 @@ pub static PY_UTILS: GILLazyPy<PyUtils> = GILLazyPy::new_py(|py| {
         none: get("none"),
         einsum: get("einsum"),
         make_diagonal: get("make_diagonal"),
-        make_bytes: get("make_bytes"),
         print: get("print"),
+        tensor_to_bytes: get("tensor_to_bytes"),
+        tensor_from_bytes: get("tensor_from_bytes"),
     }
 });
 
@@ -148,12 +150,6 @@ pub fn einops_repeat(
         .extract(py)
 }
 
-#[apply(make_py_func)]
-#[py_ident(py)]
-pub fn make_bytes(bytes: &[u8]) -> PyResult<PyObject> {
-    PY_UTILS.make_bytes.call(py, (bytes,), None)
-}
-
 #[apply(make_py_func)]
 #[py_ident(py)]
 pub fn un_flat_concat(tensor: &Tensor, split_shapes: Vec<Shape>) -> PyResult<Vec<Tensor>> {
