@@ -1,4 +1,4 @@
-use std::collections::HashMap;
+use crate::hashmaps::FxHashMap as HashMap;
 
 pub struct UnionFind(Vec<usize>);
 
